<?php

/**
 * REST API: SP_REST_Actions_Controller class
 *
 * @author   StorePilot
 * @category API
 * @package  StorePilot/API
 * @since    1.1.2
 */

if (!defined('ABSPATH')) {
  exit;
}

/**
 * Translation controller used to provide i18n via the REST API.
 *
 * @since 1.0.0
 *
 * @see SP_REST_Posts_Controller
 */
class SP_REST_Translation_Controller
{

  /**
   * Endpoint namespace.
   *
   * @var string
   */
  protected $namespace = 'wc/sp/v1';

  /**
   * Register the routes for custom ordering.
   */
  public function register_routes()
  {
    register_rest_route(
      $this->namespace,
      '/translation',
      array(
        array(
          'methods'             => WP_REST_Server::READABLE,
          'callback'            => array($this, 'get_translation'),
          'permission_callback' => array($this, 'get_translation_permissions_check'),
          'args'                => $this->get_params()
        )
      )
    );
  }

  /**
   * Checks if a given request has access read.
   *
   * @since 1.0.0
   * @access public
   *
   * @param  WP_REST_Request $request Full details about the request.
   * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
   */
  public function get_translation_permissions_check($request)
  {

    rest_send_cors_headers(null); // Allow cors when dealing with actions

    return true;
  }

  /**
   * Retrieves a collection of posts.
   *
   * @since 1.0.0
   * @access public
   *
   * @param WP_REST_Request $request Full details about the request.
   * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
   */
  public function get_translation($request)
  {

    $q = $request->get_query_params();
    $locale = $q['locale'];

    // Change locale if given.
    if (!empty($locale)) {
      switch_to_locale($locale);
    }

    return wp_send_json([

      // StorePilot only @todo - check if some fit with WordPress translation
      [key => "Could not connect, please verify url.", value => __("Could not connect, please verify url.", "storepilot")],
      [key => "Edit variations", value => __("Edit variations", "storepilot")],
      [key => "for", value => __("for", "storepilot")],
      [key => "Not found", value => __("Not found", "storepilot")],
      [key => "Detach", value => __("Detach", "storepilot")],
      [key => "Opens in default browser", value => __("Opens in default browser", "storepilot")],
      [key => "Alt text", value => __("Alt text", "storepilot")],
      [key => "Caption", value => __("Caption", "storepilot")],
      [key => "Author ID", value => __("Author ID", "storepilot")],
      [key => "Media Manager", value => __("Media Manager", "storepilot")],
      [key => "Comment status", value => __("Comment status", "storepilot")],
      [key => "Ping status", value => __("Ping status", "storepilot")],
      [key => "Media type", value => __("Media type", "storepilot")],
      [key => "Mime type", value => __("Mime type", "storepilot")],
      [key => "Sizes", value => __("Sizes", "storepilot")],
      [key => "Please select customer", value => __("Please select customer", "storepilot")],
      [key => "Please select product", value => __("Please select product", "storepilot")],
      [key => "Please select media", value => __("Please select media", "storepilot")],
      [key => "current week", value => __("current week", "storepilot")],
      [key => "current month", value => __("current month", "storepilot")],
      [key => "current year", value => __("current year", "storepilot")],
      [key => "Custom fee", value => __("Custom fee", "storepilot")],
      [key => "Using", value => __("Using", "storepilot")],
      [key => "Received", value => __("Received", "storepilot")],
      [key => "Return", value => __("Return", "storepilot")],
      [key => "Receipt for order", value => __("Receipt for order", "storepilot")],
      [key => "Stripe secret key", value => __("Stripe secret key", "storepilot")],
      [key => "find your key", value => __("find your key", "storepilot")],
      [key => "Select terminal", value => __("Select terminal", "storepilot")],
      [key => "Test terminal", value => __("Test terminal", "storepilot")],
      [key => "Barcode scanner", value => __("Barcode scanner", "storepilot")],
      [key => "Select how StorePilot should calculate the taxes", value => __("Select how StorePilot should calculate the taxes", "storepilot")],
      [key => "Invoice settings", value => __("Invoice settings", "storepilot")],
      [key => "Country", value => __("Country", "storepilot")],
      [key => "Bank account number", value => __("Bank account number", "storepilot")],
      [key => "Logo", value => __("Logo", "storepilot")],
      [key => "Purchase code", value => __("Purchase code", "storepilot")],
      [key => "Edit original", value => __("Edit original", "storepilot")],
      [key => "Invoice postal code", value => __("Invoice postal code", "storepilot")],
      [key => "Invoice city", value => __("Invoice city", "storepilot")],
      [key => "Invoice country", value => __("Invoice country", "storepilot")],
      [key => "Invoice bank account number", value => __("Invoice bank account number", "storepilot")],
      [key => "Invoice logo", value => __("Invoice logo", "storepilot")],
      [key => "Manage subscriptions", value => __("Manage subscriptions", "storepilot")],
      [key => "Activate Stripe terminal for Point of Sale", value => __("Activate Stripe terminal for Point of Sale", "storepilot")],
      [key => "Save / fetch", value => __("Save / fetch", "storepilot")],
      [key => "Tip", value => __("Tip", "storepilot")],
      [key => "Invoice company name", value => __("Invoice company name", "storepilot")],
      [key => "Invoice email", value => __("Invoice email", "storepilot")],
      [key => "Invoice phone", value => __("Invoice phone", "storepilot")],
      [key => "Tax in Point of Sale", value => __("Tax in Point of Sale", "storepilot")],
      [key => "as default", value => __("as default", "storepilot")],
      [key => "Store Keeping Unit", value => __("Store Keeping Unit", "storepilot")],
      [key => "To manage your subscriptions, please visit", value => __("To manage your subscriptions, please visit", "storepilot")],
      [key => "There you can also detach licenses from machines, so it can be attached to other machines.", value => __("There you can also detach licenses from machines, so it can be attached to other machines.", "storepilot")],
      [key => "Uses the products", value => __("Uses the products", "storepilot")],
      [key => "Type which meta tag the barcode scanner should search for", value => __("Type which meta tag the barcode scanner should search for", "storepilot")],
      [key => "You can also type 'product_id' to use the product id's", value => __("You can also type 'product_id' to use the product id's", "storepilot")],
      [key => "Set identical to your WooCommerce settings", value => __("Set identical to your WooCommerce settings", "storepilot")],
      [key => "Fees", value => __("Fees", "storepilot")],
      [key => "Customer ID", value => __("Customer ID", "storepilot")],
      [key => "Discount total", value => __("Discount total", "storepilot")],
      [key => "Cart tax", value => __("Cart tax", "storepilot")],
      [key => "Tax included in prices?", value => __("Tax included in prices?", "storepilot")],
      [key => "Parent ID", value => __("Parent ID", "storepilot")],
      [key => "Receipt", value => __("Receipt", "storepilot")],
      [key => "Invoice", value => __("Invoice", "storepilot")],
      [key => "Delivery notice", value => __("Delivery notice", "storepilot")],
      [key => "Please select order", value => __("Please select order", "storepilot")],
      [key => "Email address is required", value => __("Email address is required", "storepilot")],
      [key => "Other fees", value => __("Other fees", "storepilot")],
      [key => "Internal note", value => __("Internal note", "storepilot")],
      [key => "Delivery notice for order #", value => __("Delivery notice for order #", "storepilot")],
      [key => "To account number", value => __("To account number", "storepilot")],
      [key => "Invoice for order #", value => __("Invoice for order #", "storepilot")],
      [key => "To:", value => __("To:", "storepilot")],
      [key => "Could not create order", value => __("Could not create order", "storepilot")],
      [key => "Publish set", value => __("Publish set", "storepilot")],
      [key => "Draft set", value => __("Draft set", "storepilot")],
      [key => "Pending set", value => __("Pending set", "storepilot")],
      [key => "Private set", value => __("Private set", "storepilot")],
      [key => "Replaced", value => __("Replaced", "storepilot")],
      [key => "Appended", value => __("Appended", "storepilot")],
      [key => "Prepended", value => __("Prepended", "storepilot")],
      [key => "Increased", value => __("Increased", "storepilot")],
      [key => "Decreased", value => __("Decreased", "storepilot")],
      [key => "Removed", value => __("Removed", "storepilot")],
      [key => "Your browser doesnt support this type of copy", value => __("Your browser doesnt support this type of copy", "storepilot")],
      [key => "Tag Created", value => __("Tag Created", "storepilot")],
      [key => "Added to tag", value => __("Added to tag", "storepilot")],
      [key => "Added to category", value => __("Added to category", "storepilot")],
      [key => "Shop is already attached", value => __("Shop is already attached", "storepilot")],
      [key => "Site is removed", value => __("Site is removed", "storepilot")],
      [key => "Detach canceled", value => __("Detach canceled", "storepilot")],
      [key => "Total (Inc.)", value => __("Total (Inc.)", "storepilot")],
      [key => "Select Customer", value => __("Select Customer", "storepilot")],
      [key => "Discard changes", value => __("Discard changes", "storepilot")],
      [key => "Discard", value => __("Discard", "storepilot")],
      [key => "to update", value => __("to update", "storepilot")],
      [key => "View reports for", value => __("View reports for", "storepilot")],
      [key => "Fetching web store data...", value => __("Fetching web store data...", "storepilot")],
      [key => "Total items", value => __("Total items", "storepilot")],
      [key => "WordPress Dashboard", value => __("WordPress Dashboard", "storepilot")],
      [key => "Always using Secure Socket Layer", value => __("Always using Secure Socket Layer", "storepilot")],
      [key => "Supports Secure Socket Layer", value => __("Supports Secure Socket Layer", "storepilot")],
      [key => "StorePilot Helper", value => __("StorePilot Helper", "storepilot")],
      [key => "Activated v.", value => __("Activated v.", "storepilot")],
      [key => "Not active", value => __("Not active", "storepilot")],
      [key => "Please enable", value => __("Please enable", "storepilot")],
      [key => "Using StorePilot Pro edition?", value => __("Using StorePilot Pro edition?", "storepilot")],
      [key => "Webshop status", value => __("Webshop status", "storepilot")],
      [key => "Get by period", value => __("Get by period", "storepilot")],
      [key => "Get by range", value => __("Get by range", "storepilot")],
      [key => "Average sales", value => __("Average sales", "storepilot")],
      [key => "Net sales", value => __("Net sales", "storepilot")],
      [key => "Customer purchases", value => __("Customer purchases", "storepilot")],
      [key => "Total refunds", value => __("Total refunds", "storepilot")],
      [key => "Total discounts", value => __("Total discounts", "storepilot")],
      [key => "Charts grouped by", value => __("Charts grouped by", "storepilot")],
      [key => "Incoming", value => __("Incoming", "storepilot")],
      [key => "Month", value => __("Month", "storepilot")],
      [key => "Week", value => __("Week", "storepilot")],
      [key => "Day", value => __("Day", "storepilot")],
      [key => "Activity", value => __("Activity", "storepilot")],
      [key => "Products purchased", value => __("Products purchased", "storepilot")],
      [key => "Taxed", value => __("Taxed", "storepilot")],
      [key => "Best sellers", value => __("Best sellers", "storepilot")],
      [key => "Point of Sale", value => __("Point of Sale", "storepilot")],
      [key => "No shops attached, please", value => __("No shops attached, please", "storepilot")],
      [key => "a store", value => __("a store", "storepilot")],
      [key => "Sign up", value => __("Sign up", "storepilot")],
      [key => "Trial ends", value => __("Trial ends", "storepilot")],
      [key => "to keep using", value => __("to keep using", "storepilot")],
      [key => "after expiration", value => __("after expiration", "storepilot")],
      [key => "Hide notice", value => __("Hide notice", "storepilot")],
      [key => "Install & Relaunch", value => __("Install & Relaunch", "storepilot")],
      [key => "An update has been downloaded.", value => __("An update has been downloaded.", "storepilot")],
      [key => "License expired!", value => __("License expired!", "storepilot")],
      [key => "Please", value => __("Please", "storepilot")],
      [key => "upgrade", value => __("upgrade", "storepilot")],
      [key => "Automatic updates and reactivation on other machines has been blocked.", value => __("Automatic updates and reactivation on other machines has been blocked.", "storepilot")],
      [key => "for a low cost", value => __("for a low cost", "storepilot")],
      [key => "Shops", value => __("Shops", "storepilot")],
      [key => "Search by Term", value => __("Search by Term", "storepilot")],
      [key => "Search by Slug", value => __("Search by Slug", "storepilot")],
      [key => "Search by SKU", value => __("Search by SKU", "storepilot")],
      [key => "Search by", value => __("Search by", "storepilot")],
      [key => "Drag and drop products from table or grid", value => __("Drag and drop products from table or grid", "storepilot")],
      [key => "Category title", value => __("Category title", "storepilot")],
      [key => "Category slug.", value => __("Category slug.", "storepilot")],
      [key => "Order notice", value => __("Order notice", "storepilot")],
      [key => "products", value => __("products", "storepilot")],
      [key => "Warning! This is an early version, read the", value => __("Warning! This is an early version, read the", "storepilot")],
      [key => "documentation", value => __("documentation", "storepilot")],
      [key => "before use.", value => __("before use.", "storepilot")],
      [key => "Fee / Discount", value => __("Fee / Discount", "storepilot")],
      [key => "Picking list", value => __("Picking list", "storepilot")],
      [key => "From", value => __("From", "storepilot")],
      [key => "Paid", value => __("Paid", "storepilot")],
      [key => "Click to add product", value => __("Click to add product", "storepilot")],
      [key => "Set as featured", value => __("Set as featured", "storepilot")],
      [key => "EAN / GTIN", value => __("EAN / GTIN", "storepilot")],
      [key => "A0-103", value => __("A0-103", "storepilot")],
      [key => "Title and slug", value => __("Title and slug", "storepilot")],
      [key => "Price and sale", value => __("Price and sale", "storepilot")],
      [key => "customers", value => __("customers", "storepilot")],
      [key => "settings", value => __("settings", "storepilot")],
      [key => "Machine name", value => __("Machine name", "storepilot")],
      [key => "- Stored automatically", value => __("- Stored automatically", "storepilot")],
      [key => "Decide which font to use for PDF exports", value => __("Decide which font to use for PDF exports", "storepilot")],
      [key => "Terminal options - (In Person Sales)", value => __("Terminal options - (In Person Sales)", "storepilot")],
      [key => "Using the", value => __("Using the", "storepilot")],
      [key => "barcode parameter", value => __("barcode parameter", "storepilot")],
      [key => "as default, or the", value => __("as default, or the", "storepilot")],
      [key => "if StorePilot helper is not installed.", value => __("if StorePilot helper is not installed.", "storepilot")],
      [key => "You can also type", value => __("You can also type", "storepilot")],
      [key => "Find your keys", value => __("Find your keys", "storepilot")],
      [key => "SumUp Affiliate Key", value => __("SumUp Affiliate Key", "storepilot")],
      [key => "(US Only)", value => __("(US Only)", "storepilot")],
      [key => "Get a terminal", value => __("Get a terminal", "storepilot")],
      [key => "Invoice custom text", value => __("Invoice custom text", "storepilot")],
      [key => "Custom text", value => __("Custom text", "storepilot")],
      [key => "to use the product id's.", value => __("to use the product id's.", "storepilot")],
      [key => "PDF Font Family", value => __("PDF Font Family", "storepilot")],
      [key => "Select files", value => __("Select files", "storepilot")],
      [key => "Additional", value => __("Additional", "storepilot")],
      [key => "Attributes editor", value => __("Attributes editor", "storepilot")],
      [key => "Attach", value => __("Attach", "storepilot")],
      [key => "Attached to post", value => __("Attached to post", "storepilot")],
      [key => "Attach term", value => __("Attach term", "storepilot")],
      [key => "Attach attribute", value => __("Attach attribute", "storepilot")],
      [key => "Attach a new store", value => __("Attach a new store", "storepilot")],
      [key => "Archives", value => __("Archives", "storepilot")],
      [key => "Append", value => __("Append", "storepilot")],
      [key => "Barcode", value => __("Barcode", "storepilot")],
      [key => "Bulk edit", value => __("Bulk edit", "storepilot")],
      [key => "Bullet list", value => __("Bullet list", "storepilot")],
      [key => "Bought", value => __("Bought!", "storepilot")],
      [key => "By", value => __("By", "storepilot")],
      [key => "Cash", value => __("Cash", "storepilot")],
      [key => "Cash out", value => __("Cash out", "storepilot")],
      [key => "Template", value => __("Template", "storepilot")],
      [key => "Clear sale", value => __("Clear sale", "storepilot")],
      [key => "Last modified", value => __("Last modified", "storepilot")],
      [key => "Created via", value => __("Created via", "storepilot")],
      [key => "Cart hash", value => __("Cart hash", "storepilot")],
      [key => "Paid on", value => __("Paid on", "storepilot")],
      [key => "Cart hash", value => __("Cart hash", "storepilot")],
      [key => "Custom sorting", value => __("Custom sorting", "storepilot")],
      [key => "Decrease", value => __("Decrease", "storepilot")],
      [key => "Deactivate", value => __("Deactivate", "storepilot")],
      [key => "Delete product permanently", value => __("Delete product permanently", "storepilot")],
      [key => "Delete all permanently", value => __("Delete all permanently", "storepilot")],
      [key => "Delete variation", value => __("Delete variation", "storepilot")],
      [key => "Didn`t buy", value => __("Didn`t buy", "storepilot")],
      [key => "Display", value => __("Display", "storepilot")],
      [key => "Draft", value => __("Draft", "storepilot")],
      [key => "Drop attributes here", value => __("Drop attributes here", "storepilot")],
      [key => "Drop product here", value => __("Drop product here", "storepilot")],
      [key => "Duplicate product", value => __("Duplicate product", "storepilot")],
      [key => "Duplicate tag", value => __("Duplicate tag", "storepilot")],
      [key => "Duplicate category", value => __("Duplicate category", "storepilot")],
      [key => "Duplicate customer", value => __("Duplicate customer", "storepilot")],
      [key => "Duplicate order", value => __("Duplicate order", "storepilot")],
      [key => "Edit sale", value => __("Edit sale", "storepilot")],
      [key => "Filter categories", value => __("Filter categories", "storepilot")],
      [key => "Filter search", value => __("Filter search", "storepilot")],
      [key => "Gallery", value => __("Gallery", "storepilot")],
      [key => "Global attribute editor", value => __("Global attribute editor", "storepilot")],
      [key => "Global attribute term editor", value => __("Global attribute term editor", "storepilot")],
      [key => "Install / Update", value => __("Install / Update", "storepilot")],
      [key => "Label", value => __("Label", "storepilot")],
      [key => "Menu order position", value => __("Menu order position", "storepilot")],
      [key => "Missing", value => __("Missing", "storepilot")],
      [key => "Published products using term", value => __("Published products using term", "storepilot")],
      [key => "Might be hidden for your customers", value => __("Might be hidden for your customers", "storepilot")],
      [key => "New", value => __("New", "storepilot")],
      [key => "Number", value => __("Number", "storepilot")],
      [key => "Notify", value => __("Notify", "storepilot")],
      [key => "Open", value => __("Open", "storepilot")],
      [key => "Option", value => __("Option", "storepilot")],
      [key => "Options", value => __("Options", "storepilot")],
      [key => "Parent id is not 0", value => __("Parent id is not 0", "storepilot")],
      [key => "Pay with card", value => __("Pay with card", "storepilot")],
      [key => "Per page", value => __("Per page", "storepilot")],
      [key => "Percentage", value => __("Percentage", "storepilot")],
      [key => "Per row", value => __("Per row", "storepilot")],
      [key => "Please input", value => __("Please input", "storepilot")],
      [key => "Prepend", value => __("Prepend", "storepilot")],
      [key => "Price & sale", value => __("Price & sale", "storepilot")],
      [key => "Private", value => __("Private", "storepilot")],
      [key => "Rack", value => __("Rack", "storepilot")],
      [key => "Reset to 0", value => __("Reset to 0", "storepilot")],
      [key => "Refresh", value => __("Refresh", "storepilot")],
      [key => "renaming", value => __("renaming", "storepilot")],
      [key => "Replace", value => __("Replace", "storepilot")],
      [key => "Remove from category", value => __("Remove from category", "storepilot")],
      [key => "Rename", value => __("Rename", "storepilot")],
      [key => "Role", value => __("Role", "storepilot")],
      [key => "Sale active", value => __("Sale active", "storepilot")],
      [key => "Sale flash", value => __("Sale flash", "storepilot")],
      [key => "Sale inactive", value => __("Sale inactive", "storepilot")],
      [key => "Sale scheduled", value => __("Sale scheduled", "storepilot")],
      [key => "Selected", value => __("Selected", "storepilot")],
      [key => "Select variation", value => __("Select variation", "storepilot")],
      [key => "Select image", value => __("Select image", "storepilot")],
      [key => "Select images", value => __("Select images", "storepilot")],
      [key => "Shortcut", value => __("Shortcut", "storepilot")],
      [key => "Shortcut: delete", value => __("Shortcut: delete", "storepilot")],
      [key => "Start composing...", value => __("Start composing...", "storepilot")],
      [key => "Tag settings", value => __("Tag settings", "storepilot")],
      [key => "Tag title", value => __("Tag title", "storepilot")],
      [key => "Tag slug", value => __("Tag slug", "storepilot")],
      [key => "Tax is included in prices", value => __("Tax is included in prices", "storepilot")],
      [key => "Tax is excluded from prices", value => __("Tax is excluded from prices", "storepilot")],
      [key => "License for StorePilot", value => __("License for StorePilot", "storepilot")],
      [key => "This cannot be undone!", value => __("This cannot be undone!", "storepilot")],
      [key => "This page", value => __("This page", "storepilot")],
      [key => "This product is trashed!", value => __("This product is trashed!", "storepilot")],
      [key => "- Is currently active on this machine", value => __("- Is currently active on this machine", "storepilot")],
      [key => "Title & slug", value => __("Title & slug", "storepilot")],
      [key => "To", value => __("To", "storepilot")],
      [key => "Trash all", value => __("Trash all", "storepilot")],
      [key => "Unselect all", value => __("Unselect all", "storepilot")],
      [key => "URL", value => __("URL", "storepilot")],
      [key => "Value", value => __("Value", "storepilot")],
      [key => "Variation", value => __("Variation", "storepilot")],
      [key => "Visible", value => __("Visible", "storepilot")],
      [key => "Waiting for payment...", value => __("Waiting for payment...", "storepilot")],
      [key => "You are authorized", value => __("You are authorized", "storepilot")],
      [key => "Meta key", value => __("Meta key", "storepilot")],
      [key => "Meta data", value => __("Meta data", "storepilot")],

      // Inherited from WooCommerce
      [key => "Year", value => __("Year", "woocommerce")],
      [key => "Subtotal", value => __("Subtotal", "woocommerce")],
      [key => "Quantity", value => __("Quantity", "woocommerce")],
      [key => "Dashboard", value => __("Dashboard", "woocommerce")],
      [key => "Orders", value => __("Orders", "woocommerce")],
      [key => "Out of stock", value => __("Out of stock", "woocommerce")],
      [key => "Currency position", value => __("Currency position", "woocommerce")],
      [key => "Active plugins", value => __("Active plugins", "woocommerce")],
      [key => "Language", value => __("Language", "woocommerce")],
      [key => "Enabled", value => __("Enabled", "woocommerce")],
      [key => "Currency", value => __("Currency", "woocommerce")],
      [key => "Total sales", value => __("Total sales", "woocommerce")],
      [key => "Customer note", value => __("Customer note", "woocommerce")],
      [key => "Log", value => __("Log", "woocommerce")],
      [key => "Subject", value => __("Subject", "woocommerce")],
      [key => "Order Total", value => __("Order Total", "woocommerce")],
      [key => "Discount total.", value => __("Discount total.", "woocommerce")],
      [key => "Discount:", value => __("Discount:", "woocommerce")],
      [key => "In stock", value => __("In stock", "woocommerce")],
      [key => "Transaction ID", value => __("Transaction ID", "woocommerce")],
      [key => "Total shipping", value => __("Total shipping", "woocommerce")],
      [key => "Shipping tax amount", value => __("Shipping tax amount", "woocommerce")],
      [key => "Payment method:", value => __("Payment method:", "woocommerce")],
      [key => "Payment method title.", value => __("Payment method title.", "woocommerce")],
      [key => "Parent order ID.", value => __("Parent order ID.", "woocommerce")],
      [key => "Discount total tax.", value => __("Discount total tax.", "woocommerce")],
      [key => "Company", value => __("Company", "woocommerce")],
      [key => "Address line 1", value => __("Address line 1", "woocommerce")],
      [key => "Address line 2", value => __("Address line 2", "woocommerce")],
      [key => "State", value => __("State", "woocommerce")],
      [key => "Qty", value => __("Qty", "woocommerce")],
      [key => "Tax lines data.", value => __("Tax lines data.", "woocommerce")],
      [key => "Rate code", value => __("Rate code", "woocommerce")],
      [key => "Rate", value => __("Rate", "woocommerce")],
      [key => "Code", value => __("Code", "woocommerce")],
      [key => "Compound", value => __("Compound", "woocommerce")],
      [key => "Shipping tax total.", value => __("Shipping tax total.", "woocommerce")],
      [key => "Total tax", value => __("Total tax", "woocommerce")],
      [key => "Refund reason.", value => __("Refund reason.", "woocommerce")],
      [key => "Refunds", value => __("Refunds", "woocommerce")],
      [key => "Coupon line data.", value => __("Coupon line data.", "woocommerce")],
      [key => "Shipping lines", value => __("Shipping lines", "woocommerce")],
      [key => "Shipping instance ID.", value => __("Shipping instance ID.", "woocommerce")],
      [key => "Tax discount", value => __("Tax discount", "woocommerce")],
      [key => "Last month", value => __("Last month", "woocommerce")],
      [key => "ASC", value => __("ASC", "woocommerce")],
      [key => "DESC", value => __("DESC", "woocommerce")],
      [key => "Type to search for a customer", value => __("Type to search for a customer", "woocommerce")],
      [key => "Phone", value => __("Phone", "woocommerce")],
      [key => "Company name", value => __("Company name", "woocommerce")],
      [key => "Address", value => __("Address", "woocommerce")],
      [key => "Postal code", value => __("Postal code", "woocommerce")],
      [key => "City", value => __("City", "woocommerce")],
      [key => "Store Address", value => __("Store Address", "woocommerce")],
      [key => "On-hold", value => __("On-hold", "woocommerce")],
      [key => "Failed", value => __("Failed", "woocommerce")],
      [key => "Cancelled", value => __("Cancelled", "woocommerce")],
      [key => "Refunded", value => __("Refunded", "woocommerce")],
      [key => "Processing", value => __("Processing", "woocommerce")],
      [key => "Any", value => __("Any", "woocommerce")],
      [key => "Order Status", value => __("Order Status", "woocommerce")],
      [key => "Billing", value => __("Billing", "woocommerce")],
      [key => "Order notes", value => __("Order notes", "woocommerce")],
      [key => "Guest", value => __("Guest", "woocommerce")],
      [key => "Order details", value => __("Order details", "woocommerce")],
      [key => "Customer", value => __("Customer", "woocommerce")],
      [key => "Shop", value => __("Shop", "woocommerce")],
      [key => "Authorize", value => __("Authorize", "woocommerce")],
      [key => "Loading...", value => __("Loading...", "woocommerce")],
      [key => "Load more", value => __("Load more", "woocommerce")],
      [key => "Search for a product...", value => __("Search for a product...", "woocommerce")],
      [key => "Amount", value => __("Amount", "woocommerce")],
      [key => "Checkout", value => __("Checkout", "woocommerce")],
      [key => "Order", value => __("Order", "woocommerce")],
      [key => "Export", value => __("Export", "woocommerce")],
      [key => "orders", value => __("orders", "woocommerce")],
      [key => "Pending payment", value => __("Pending payment", "woocommerce")],
      [key => "Import", value => __("Import", "woocommerce")],
      [key => "Yes", value => __("Yes", "woocommerce")],
      [key => "Validate", value => __("Validate", "woocommerce")],
      [key => "Completed", value => __("Completed", "woocommerce")],
      [key => "Order key.", value => __("Order key.", "woocommerce")],
      [key => "Customers IP address.", value => __("Customer's IP address.", "woocommerce")],
      [key => "Total amount spent.", value => __("Total amount spent.", "woocommerce")],
      [key => "Total of orders placed.", value => __("Total of orders placed.", "woocommerce")],
      [key => "WooCommerce version", value => __("WooCommerce version", "woocommerce")],
      [key => "Paying customer", value => __("Paying customer", "woocommerce")],
      [key => "Activate", value => __("Activate", "woocommerce")],
      [key => "Actions", value => __("Actions", "woocommerce")],
      [key => "Advanced", value => __("Advanced", "woocommerce")],
      [key => "Add new product", value => __("Add new product", "woocommerce")],
      [key => "Add new tag", value => __("Add new tag", "woocommerce")],
      [key => "Add new category", value => __("Add new category", "woocommerce")],
      [key => "Add new order", value => __("Add new order", "woocommerce")],
      [key => "Attribute", value => __("Attribute", "woocommerce")],
      [key => "Attributes", value => __("Attributes", "woocommerce")],
      [key => "All", value => __("All", "woocommerce")],
      [key => "Allow", value => __("Allow", "woocommerce")],
      [key => "Allow backorders?", value => __("Allow backorders?", "woocommerce")],
      [key => "Allow, but notify customer", value => __("Allow, but notify customer", "woocommerce")],
      [key => "Apply", value => __("Apply", "woocommerce")],
      [key => "Both", value => __("Both", "woocommerce")],
      [key => "Cancel", value => __("Cancel", "woocommerce")],
      [key => "Category", value => __("Category", "woocommerce")],
      [key => "Category settings", value => __("Category settings", "woocommerce")],
      [key => "Categories", value => __("Categories", "woocommerce")],
      [key => "Clear", value => __("Clear", "woocommerce")],
      [key => "Close", value => __("Close", "woocommerce")],
      [key => "Created at", value => __("Created at", "woocommerce")],
      [key => "Cross-sells", value => __("Cross-sells", "woocommerce")],
      [key => "CrossSells", value => __("Cross-sells", "woocommerce")],
      [key => "Customers", value => __("Customers", "woocommerce")],
      [key => "Count", value => __("Count", "woocommerce")],
      [key => "Copy link", value => __("Copy link", "woocommerce")],
      [key => "Complete", value => __("Complete", "woocommerce")],
      [key => "Create", value => __("Create", "woocommerce")],
      [key => "Date", value => __("Date", "woocommerce")],
      [key => "Delete", value => __("Delete", "woocommerce")],
      [key => "Delete permanently", value => __("Delete permanently", "woocommerce")],
      [key => "Default", value => __("Default", "woocommerce")],
      [key => "Description", value => __("Description", "woocommerce")],
      [key => "Display type", value => __("Display type", "woocommerce")],
      [key => "Do not allow", value => __("Do not allow", "woocommerce")],
      [key => "Downloads", value => __("Downloads", "woocommerce")],
      [key => "Downloadable", value => __("Downloadable", "woocommerce")],
      [key => "Downloadable files", value => __("Downloadable files", "woocommerce")],
      [key => "Download limit", value => __("Download limit", "woocommerce")],
      [key => "Download expiry", value => __("Download expiry", "woocommerce")],
      [key => "Duplicate", value => __("Duplicate", "woocommerce")],
      [key => "Edit", value => __("Edit", "woocommerce")],
      [key => "Email", value => __("Email", "woocommerce")],
      [key => "Enable", value => __("Enable", "woocommerce")],
      [key => "Featured", value => __("Featured", "woocommerce")],
      [key => "Filter", value => __("Filter", "woocommerce")],
      [key => "Fixed amount", value => __("Fixed amount", "woocommerce")],
      [key => "First name", value => __("First name", "woocommerce")],
      [key => "FirstName", value => __("First name", "woocommerce")],
      [key => "From:", value => __("From:", "woocommerce")],
      [key => "General", value => __("General", "woocommerce")],
      [key => "Grouped product", value => __("Grouped product", "woocommerce")],
      [key => "Height", value => __("Height", "woocommerce")],
      [key => "ID", value => __("ID", "woocommerce")],
      [key => "Items", value => __("Items", "woocommerce")],
      [key => "Image", value => __("Image", "woocommerce")],
      [key => "Increase", value => __("Increase", "woocommerce")],
      [key => "Inventory", value => __("Inventory", "woocommerce")],
      [key => "Last name", value => __("Last name", "woocommerce")],
      [key => "LastName", value => __("Last name", "woocommerce")],
      [key => "Length", value => __("Length", "woocommerce")],
      [key => "Manage stock", value => __("Manage stock", "woocommerce")],
      [key => "Name", value => __("Name", "woocommerce")],
      [key => "No", value => __("No", "woocommerce")],
      [key => "None", value => __("None", "woocommerce")],
      [key => "There are no reviews yet.", value => __("No reviews yet", "woocommerce")],
      [key => "Order by", value => __("Order by", "woocommerce")],
      [key => "Pending", value => __("Pending", "woocommerce")],
      [key => "Price", value => __("Price", "woocommerce")],
      [key => "Product", value => __("Product", "woocommerce")],
      [key => "Products", value => __("Products", "woocommerce")],
      [key => "Position", value => __("Position", "woocommerce")],
      [key => "Published", value => __("Published", "woocommerce")],
      [key => "Purchase note", value => __("Purchase note", "woocommerce")],
      [key => "PurchaseNote", value => __("Purchase note", "woocommerce")],
      [key => "Reviews", value => __("Reviews", "woocommerce")],
      [key => "Regular price", value => __("Regular price", "woocommerce")],
      [key => "Remove", value => __("Remove", "woocommerce")],
      [key => "Sale!", value => __("Sale!", "woocommerce")],
      [key => "Sale", value => __("Sale", "woocommerce")],
      [key => "Sale price", value => __("Sale price", "woocommerce")],
      [key => "Save", value => __("Save", "woocommerce")],
      [key => "Schedule", value => __("Schedule", "woocommerce")],
      [key => "Search", value => __("Search", "woocommerce")],
      [key => "Select", value => __("Select", "woocommerce")],
      [key => "Settings", value => __("Settings", "woocommerce")],
      [key => "Stock", value => __("In stock", "woocommerce")],
      [key => "Show", value => __("Show", "woocommerce")],
      [key => "Short description", value => __("Short description", "woocommerce")],
      [key => "ShortDescription", value => __("Short description", "woocommerce")],
      [key => "Shipping", value => __("Shipping", "woocommerce")],
      [key => "Simple product", value => __("Simple product", "woocommerce")],
      [key => "SKU", value => __("SKU", "woocommerce")],
      [key => "Slug", value => __("Slug", "woocommerce")],
      [key => "Sold individually", value => __("Sold individually", "woocommerce")],
      [key => "Sort by:", value => __("Sort by:", "woocommerce")],
      [key => "Status", value => __("Status", "woocommerce")],
      [key => "Stock Keeping Unit", value => __("Stock keeping unit", "woocommerce")],
      [key => "Stock quantity", value => __("Stock quantity", "woocommerce")],
      [key => "Subcategories", value => __("Subcategories", "woocommerce")],
      [key => "Tag", value => __("Tag", "woocommerce")],
      [key => "Tags", value => __("Tags", "woocommerce")],
      [key => "Tax", value => __("Tax", "woocommerce")],
      [key => "Taxable", value => __("Taxable", "woocommerce")],
      [key => "Tax status", value => __("Tax status", "woocommerce")],
      [key => "Tax class", value => __("Tax class", "woocommerce")],
      [key => "Terms", value => __("Terms", "woocommerce")],
      [key => "Title", value => __("Title", "woocommerce")],
      [key => "Total", value => __("Total", "woocommerce")],
      [key => "Trash", value => __("Trash", "woocommerce")],
      [key => "Trashed", value => __("Trashed", "woocommerce")],
      [key => "Type", value => __("Type", "woocommerce")],
      [key => "Update", value => __("Update", "woocommerce")],
      [key => "Upsells", value => __("Upsells", "woocommerce")],
      [key => "Username", value => __("Username", "woocommerce")],
      [key => "Variations", value => __("Variations", "woocommerce")],
      [key => "Variable product", value => __("Variable product", "woocommerce")],
      [key => "View", value => __("View", "woocommerce")],
      [key => "Virtual", value => __("Virtual", "woocommerce")],
      [key => "Weight", value => __("Weight", "woocommerce")],
      [key => "Width", value => __("Width", "woocommerce")],
      [key => "Yes", value => __("Yes", "woocommerce")]
    ]);
  }

  /**
   * Retrieves the query params for collections of attachments.
   *
   * @since 1.0.0
   * @access public
   *
   * @return array Query parameters for the attachment collection as an array.
   */
  public function get_params()
  {
    $params['status']['default'] = 'inherit';
    $params['status']['items']['enum'] = array('inherit', 'private', 'trash');

    $params['locale'] = array(
      'default'           => null,
      'description'       => __('Language code to retrieve translation'),
      'type'              => 'string'
    );

    return $params;
  }
}
